@@ -1,4 +1,4 @@
-# $Id: Protocol.pm,v 1.26 1997/02/11 13:47:39 aas Exp $
+# $Id: Protocol.pm,v 1.27 1997/04/05 12:38:06 aas Exp $
 
 package LWP::Protocol;
 
@@ -6,6 +6,12 @@ package LWP::Protocol;
 
 LWP::Protocol - Base class for LWP protocols
 
+=head1 SYNOPSIS
+
+ package LWP::Protocol::foo;
+ require LWP::Protocol;
+ @ISA=qw(LWP::Protocol);
+
 =head1 DESCRIPTION
 
 This class is used a the base class for all protocol implementations
