@@ -1,15 +1,17 @@
 package URI::URL;
 
-$VERSION = "4.09";   # $Date: 1997/01/26 14:11:08 $
+$VERSION = "4.10";   # $Date: 1997/04/04 11:08:26 $
 sub Version { $VERSION; }
 
 require 5.002;
 
 require Exporter;
-require AutoLoader;
-@ISA = qw(Exporter AutoLoader);
+@ISA = qw(Exporter);
 @EXPORT = qw(url);
 
+require AutoLoader;
+*AUTOLOAD = \&AutoLoader::AUTOLOAD;
+
 use Carp ();
 
 # Basic lexical elements, taken from RFC 1738:
